Script 'mail_helper' called by obssrc
Hello community,

here is the log from the commit of package python-tornado6 for openSUSE:Factory 
checked in at 2026-03-26 21:07:25
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Comparing /work/SRC/openSUSE:Factory/python-tornado6 (Old)
 and      /work/SRC/openSUSE:Factory/.python-tornado6.new.8177 (New)
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Package is "python-tornado6"

Thu Mar 26 21:07:25 2026 rev:23 rq:1342193 version:6.5.5

Changes:
--------
--- /work/SRC/openSUSE:Factory/python-tornado6/python-tornado6.changes  
2026-03-14 22:21:10.218087682 +0100
+++ 
/work/SRC/openSUSE:Factory/.python-tornado6.new.8177/python-tornado6.changes    
    2026-03-27 06:49:17.957457574 +0100
@@ -1,0 +2,6 @@
+Tue Mar 24 09:06:35 UTC 2026 - Dirk Müller <[email protected]>
+
+- add pycares-getaddrinfo.patch to increase compatibility with
+  newer pycares versions
+
+-------------------------------------------------------------------

New:
----
  pycares-getaddrinfo.patch

----------(New B)----------
  New:
- add pycares-getaddrinfo.patch to increase compatibility with
  newer pycares versions
----------(New E)----------

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Other differences:
------------------
++++++ python-tornado6.spec ++++++
--- /var/tmp/diff_new_pack.7Ve78V/_old  2026-03-27 06:49:18.481479153 +0100
+++ /var/tmp/diff_new_pack.7Ve78V/_new  2026-03-27 06:49:18.485479318 +0100
@@ -29,6 +29,7 @@
 Patch0:         ignore-resourcewarning-doctests.patch
 # PATCH-FIX-UPSTREAM fix-tests-with-curl-8-19.patch 
gh#tornadoweb/tornado@de5e943
 Patch1:         fix-tests-with-curl-8-19.patch
+Patch2:         pycares-getaddrinfo.patch
 BuildRequires:  %{python_module base >= 3.8}
 BuildRequires:  %{python_module devel}
 BuildRequires:  %{python_module pip}

++++++ pycares-getaddrinfo.patch ++++++
Index: tornado-6.5.5/tornado/platform/caresresolver.py
===================================================================
--- tornado-6.5.5.orig/tornado/platform/caresresolver.py
+++ tornado-6.5.5/tornado/platform/caresresolver.py
@@ -66,10 +66,10 @@ class CaresResolver(Resolver):
         if is_valid_ip(host):
             addresses = [host]
         else:
             # gethostbyname doesn't take callback as a kwarg
             fut = Future()  # type: Future[Tuple[Any, Any]]
-            self.channel.gethostbyname(
-                host, family, lambda result, error: fut.set_result((result, 
error))
+            self.channel.getaddrinfo(
+                host=host, port=None, family=family, callback=lambda result, 
error: fut.set_result((result, error))
             )
             result, error = yield fut
             if error:
@@ -77,7 +77,7 @@ class CaresResolver(Resolver):
                     "C-Ares returned error %s: %s while resolving %s"
                     % (error, pycares.errno.strerror(error), host)
                 )
-            addresses = result.addresses
+            addresses = [x.addr[0].decode("utf-8") for x in result.nodes]
         addrinfo = []
         for address in addresses:
             if "." in address:
@@ -66,10 +66,10 @@ class CaresResolver(Resolver):
             addresses = [host]
         else:
-            # gethostbyname doesn't take callback as a kwarg
+            # getaddrinfo doesn't take callback as a kwarg
             fut = Future()  # type: Future[Tuple[Any, Any]]

Reply via email to